Otelite Core Library
This crate provides core functionality for the Otelite OpenTelemetry receiver, including telemetry data types for metrics, logs, and traces.
Re-exports
pub use telemetry::format_attribute_preview;pub use telemetry::format_attribute_value;pub use telemetry::LogRecord;pub use telemetry::Metric;pub use telemetry::Resource;pub use telemetry::Span;pub use telemetry::Trace;